"""
The most awesome hello in the world
"""
import sys


__version__ = '0.0.1'


def hello(name='World!'):
    """
    Return a greeting for the given name.
    """
    return f'Hello, {name}'


def main():
    """
    Read input from the args passed
    into the script and prints the output to stdout
    """
    args = sys.argv[1:]
    name = ' '.join(args)
    if name:
        print(hello(name))
    else:
        print(hello())


if __name__ == '__main__':
    main()



#!/usr/bin/env python3
from setuptools import setup
from hello import __version__

with open('README.rst') as f:
    readme = f.read()
with open('CHANGES.rst') as f:
    changes = f.read()

setup(
    name='hello_ehmed',
    version=__version__,
    description='describe please',
    long_description=readme + '\n\n' + changes,
    author='Ehmed Kino',
    author_email='ehmadaff@gmail.com',
    url='https://github.com/Ehmed-kino/wh_lilgarb.git',
    py_modules=['hello', ],
    license='MIT',
    entry_points={
        'console_scripts': ['hello=hello:main']
    }
)
